@@ -11,7 +11,7 @@ use std::path::PathBuf;
 
 /// Standard thread-safe error type
 pub type ThreadSafeStdError = dyn std::error::Error + Send + Sync;
-/// Standard thread-safe error type (boxed to allow translation for any std::error::Error type)
+/// Standard thread-safe error type (boxed to allow translation for any `std::error::Error` type)
 pub type BoxedThreadSafeStdError = Box<ThreadSafeStdError>;
 
 /// A slice of a path string
@@ -54,6 +54,8 @@ const HOST_OS_NAME: &str = if cfg!(all(
     "Redox"
 } else if cfg!(target_os = "illumos") {
     "illumos"
+} else if cfg!(target_os = "solaris") {
+    "solaris"
 } else {
     "unknown"
 };
